@@ -2302,7 +2302,7 @@ class Hypergraph:
 
     @classmethod
     def from_bipartite(
-        cls, B, set_names=("nodes", "edges"), name=None, static=False, use_nwhy=False
+        cls, B, set_names=("edges", "nodes"), name=None, static=False, use_nwhy=False
     ):
         """
         Static method creates a Hypergraph from a bipartite graph.
@@ -2356,7 +2356,7 @@ class Hypergraph:
         if static:
             elist = []
             for e in list(B.edges):
-                if e[0] in nodes:
+                if e[0] in edges:
                     elist.append([e[0], e[1]])
                 else:
                     elist.append([e[1], e[0]])
